/* --------------------------------------------------------------------------------------------
 * Copyright (c) Remy Suen. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_languageserver_1 = require("vscode-languageserver");
const dockerfileParser_1 = require("./parser/dockerfileParser");
const dockerDefinition_1 = require("./dockerDefinition");
const docker_1 = require("./docker");
class DockerHighlight {
    computeHighlightRanges(document, position) {
        let parser = new dockerfileParser_1.DockerfileParser();
        let dockerfile = parser.parse(document);
        let provider = new dockerDefinition_1.DockerDefinition();
        let location = provider.computeDefinition(document, position);
        let highlights = [];
        if (location === null) {
            for (let instruction of dockerfile.getCOPYs()) {
                let range = instruction.getFromValueRange();
                if (range && range.start.line === position.line && range.start.character <= position.character && position.character <= range.end.character) {
                    let stage = instruction.getFromValue();
                    for (let instruction of dockerfile.getCOPYs()) {
                        let source = instruction.getFromValue();
                        if (source === stage) {
                            highlights.push(vscode_languageserver_1.DocumentHighlight.create(instruction.getFromValueRange(), vscode_languageserver_1.DocumentHighlightKind.Read));
                        }
                    }
                    return highlights;
                }
            }
            for (let instruction of dockerfile.getInstructions()) {
                for (let variable of instruction.getVariables()) {
                    if (docker_1.Util.isInsideRange(position, variable.getNameRange())) {
                        let name = variable.getName();
                        for (let instruction of dockerfile.getInstructions()) {
                            for (let variable of instruction.getVariables()) {
                                if (variable.getName() === name) {
                                    highlights.push(vscode_languageserver_1.DocumentHighlight.create(variable.getNameRange(), vscode_languageserver_1.DocumentHighlightKind.Read));
                                }
                            }
                        }
                        return highlights;
                    }
                }
            }
        }
        else {
            highlights.push(vscode_languageserver_1.DocumentHighlight.create(location.range, vscode_languageserver_1.DocumentHighlightKind.Write));
            let definition = document.getText().substring(document.offsetAt(location.range.start), document.offsetAt(location.range.end));
            for (let from of dockerfile.getFROMs()) {
                let range = from.getBuildStageRange();
                if (range && range.start.line === location.range.start.line) {
                    for (let instruction of dockerfile.getCOPYs()) {
                        let source = instruction.getFromValue();
                        if (source === definition) {
                            highlights.push(vscode_languageserver_1.DocumentHighlight.create(instruction.getFromValueRange(), vscode_languageserver_1.DocumentHighlightKind.Read));
                        }
                    }
                    return highlights;
                }
            }
            for (let env of dockerfile.getENVs()) {
                for (let property of env.getProperties()) {
                    if (property.getName() === definition && !docker_1.Util.rangeEquals(property.getNameRange(), location.range)) {
                        highlights.push(vscode_languageserver_1.DocumentHighlight.create(property.getNameRange(), vscode_languageserver_1.DocumentHighlightKind.Write));
                    }
                }
            }
            for (let instruction of dockerfile.getInstructions()) {
                for (let variable of instruction.getVariables()) {
                    if (variable.getName() === definition) {
                        highlights.push(vscode_languageserver_1.DocumentHighlight.create(variable.getNameRange(), vscode_languageserver_1.DocumentHighlightKind.Read));
                    }
                }
            }
        }
        return highlights;
    }
}
exports.DockerHighlight = DockerHighlight;
